pro MSP_BDP_Make_sky_true, Event, input_shifts, $
						   input_CDS_pathname, output_CDS_directory
;
;   processes CDS and RAW1 images to perform necessary column, row pixel
;   reorderings to make the images "sky true"
;
;	INPUTS:
;			input_shifts:  intarr[4] of [LL,LR,UL,UR] pixel shifts
;			input_CDS_pathame
;
;	OUTPUTS:
;			output_CDS_dir, output_RAW1_dir
;
;   DPC 20050502    original code
;       20050611    added NOGUI keyword
;       20050613    fixed output directory bug
;       20050801     modified to use quad_shift.pro engine and to get
;                    file list from file (output from kokepeli_analysis.pro)
;       20050908    modified to allow calling by batch.pro
;       20060220    modified to work with sub-framed images, also (and mix of shifts and non-shifts)
;		20071125    copied and edited from "make_sky_true.pro" - this version does one image at a time
;					but it reads and writes the files, so it is pretty busy
;		20080627	fixed bugs in raw1 naming
;
;------------------------------------------------------------
;
WIDGET_CONTROL, Event.top, GET_UVALUE = PTR_struct
	s_ptr = PTR_struct.PTR_summary
	;
;
;	read the images
;
cds_name = STRTRIM(input_CDS_pathname,2)
;
test = FILE_INFO(cds_name)
if( NOT(test.exists) ) then print, "ERROR - Could not open CDS image = ",cds_name
cds_image = readfits(cds_name,header,/SILENT)
;
;   get image size to be able to tell read_raw1 if this is subframing
;
cds_image_size = SIZE(cds_image)
ncol_cds = cds_image_size[1]
nrow_cds = cds_image_size[2]
;
;   parse name for RAW1 type (expected in directory ../RAW1_RAW/ relative to CDS_RAW
;
cds_name_s = cds_name
raw1_pathname = CDS_to_RAW1_pathname(cds_name_s)
test = FILE_INFO(raw1_pathname)
if (NOT(test.exists) ) then print, "ERROR - Could not open RAW1 image = ",raw1_pathname
raw1_image = double(read_raw1(raw1_pathname,ncol_cds,nrow_cds))
;
;	decode shifts
;
LL = input_shifts[0]
LR = input_shifts[1]
UL = input_shifts[2]
UR = input_shifts[3]
;
;
if(LL eq -1 and LR eq 1 and UR eq 1 and UL eq -1) then begin
   ;
   ; this is the "old" case - it certainly needs all quad
   ; shifted. It then needs the two center columns moved
   ; one row away from center (each)
   ;
   ;    shift the CDS image
   ;
   ;    column swap, then column shift
   ;
   shifted_image_0 = quad_shift(cds_image, 0, 0)
   shifted_image_1 = quad_shift(shifted_image_0, 0, 1)
   ;
   shifted_image_0 = quad_shift(shifted_image_1, 1, 0)
   shifted_image_1 = quad_shift(shifted_image_0, 1, 1)
   ;
   shifted_image_0 = quad_shift(shifted_image_1, 2, 0)
   shifted_image_1 = quad_shift(shifted_image_0, 2, 1)
   ;
   shifted_image_0 = quad_shift(shifted_image_1, 3, 0)
   shifted_image_1 = quad_shift(shifted_image_0, 3, 1)
   cds_fixed = shifted_image_1
   ;
   ;    then the RAW1 image
   ;
   shifted_image_0 = quad_shift(raw1_image, 0, 0)
   shifted_image_1 = quad_shift(shifted_image_0, 0, 1)
   ;
   shifted_image_0 = quad_shift(shifted_image_1, 1, 0)
   shifted_image_1 = quad_shift(shifted_image_0, 1, 1)
   ;
   shifted_image_0 = quad_shift(shifted_image_1, 2, 0)
   shifted_image_1 = quad_shift(shifted_image_0, 2, 1)
   ;
   shifted_image_0 = quad_shift(shifted_image_1, 3, 0)
   shifted_image_1 = quad_shift(shifted_image_0, 3, 1)
   raw1_fixed = shifted_image_1
   ;
endif else begin
;
;   other cases, handle normally
;
    sum_shift = abs(LL) + abs(LR) + abs(UL) + abs(UR)
    ;
    ;print, "SUM_SHIFT = ",sum_shift
    ;
    no_shift = 1
    ;
    if(sum_shift gt 0) then begin
        if(LL eq -1) then begin
            cds_fixed = quad_shift(cds_image, 0, 0)
            cds_image = quad_shift(cds_fixed, 0, 1)
            raw1_fixed = quad_shift(raw1_image, 0, 0)
            raw1_image = quad_shift(raw1_fixed, 0, 1)
            cds_fixed = cds_image
            raw1_fixed = raw1_image
            ;
            no_shift = 0
        endif else begin
        	raw1_fixed = raw1_image
        	if(LL ne 0) then MSP_BDP_print_text, Event, "For Image "+FILE_BASENAME(cds_name)+$
        			" LL shift of "+STRING(format='(I)',LL)+" is unlikely, so ignoring."
        	cds_fixed = cds_image
        endelse
        ;
        if(LR eq 1) then begin
            cds_fixed = quad_shift(cds_image, 1, 0)
            cds_image = quad_shift(cds_fixed, 1, 1)
            ;
            ;   this wants a second shift
            ;
            ;cds_fixed = quad_shift(cds_image, 1, 1)
            ;cds_image = cds_fixed
            raw1_fixed = quad_shift(raw1_image, 1, 0)
            raw1_image = quad_shift(raw1_fixed, 1, 1)
            ;
            ;raw1_fixed = quad_shift(raw1_image, 1, 1)
            ;raw1_image = raw1_fixed
            cds_fixed = cds_image
            raw1_fixed = raw1_image
            ;
            no_shift = 0
        endif else begin
        	raw1_fixed = raw1_image
        	if(LR ne 0) then MSP_BDP_print_text, Event, "For Image "+FILE_BASENAME(cds_name)+$
        			" LR shift of "+STRING(format='(I)',LR)+" is unlikely, so ignoring."
        	cds_fixed = cds_image
        endelse
        ;
        if(UR eq 1) then begin
            cds_fixed = quad_shift(cds_image, 2, 0)
            cds_image = quad_shift(cds_fixed, 2, 1)
            raw1_fixed = quad_shift(raw1_image, 2, 0)
            raw1_image = quad_shift(raw1_fixed, 2, 1)
            cds_fixed = cds_image
            raw1_fixed = raw1_image
            ;
            no_shift = 0
        endif else begin
        	raw1_fixed = raw1_image
        	if(UR ne 0) then MSP_BDP_print_text, Event, "For Image "+FILE_BASENAME(cds_name)+$
        			" UR shift of "+STRING(format='(I)',UR)+" is unlikely, so ignoring."
        	cds_fixed = cds_image
        endelse
        ;
        if(UL eq -1) then begin
            cds_fixed = quad_shift(cds_image, 3, 0)
            cds_image = quad_shift(cds_fixed, 3, 1)
            raw1_fixed = quad_shift(raw1_image, 3, 0)
            raw1_image = quad_shift(raw1_fixed, 3, 1)
            cds_fixed = cds_image
            raw1_fixed = raw1_image
            ;
            no_shift = 0
        endif else begin
        	raw1_fixed = raw1_image
        	if(UL ne 0) then MSP_BDP_print_text, Event, "For Image "+FILE_BASENAME(cds_name)+$
        			" UL shift of "+STRING(format='(I)',UL)+" is unlikely, so ignoring."
        	cds_fixed = cds_image
        endelse
    endif else begin       ; no shifts needed, set names for copy
        cds_fixed = cds_image
        raw1_fixed = raw1_image
        no_shift = 1
    endelse
endelse
;
;   determine output CDS pathname
;
input_CDS_file = FILE_BASENAME(input_CDS_pathname)
this_CDS_dir = (*s_ptr).root_reduced + output_CDS_directory
output_CDS_pathname = FILEPATH(input_CDS_file, ROOT_DIR=this_CDS_dir)
;
;	and check whether the new directories exist
;
this_output_CDS_directory = FILE_DIRNAME(output_CDS_pathname)
test = FILE_INFO(this_output_CDS_directory)
if(NOT(test.exists) or NOT(test.directory)) then FILE_MKDIR, this_output_CDS_directory
;
;print, "CDS input name = ",input_CDS_pathname
;print, "CDS directory  = ",output_CDS_directory
;print, "CDS output name= ",output_CDS_pathname
;
;	update the COMMENT part of the header
;
if(NOT(no_shift)) then begin
	shifts_text = STRING(format='("LL=",i3," LR=",i3," UL=",i3," UR=",i3)',LL,LR,UL,UR)
	FXADDPAR, header, "HISTORY", "Shifted quadrants according to "+shifts_text
endif else begin
	FXADDPAR, header, "HISTORY", "No quadrants were shifted - detections overruled"
endelse
FXADDPAR, header, "HISTORY","  reduced by "+(*s_ptr).who
;
writefits, output_CDS_pathname, cds_fixed, header
;
;   determine output raw1 pathname
;
output_RAW1_pathname = CDS_to_RAW1_pathname(output_CDS_pathname)
output_RAW1_directory = FILE_DIRNAME(output_RAW1_pathname)
test = FILE_INFO(output_RAW1_directory)
if(NOT(test.exists) or NOT(test.directory)) then FILE_MKDIR, output_RAW1_directory
;
ier = write_raw1(output_RAW1_pathname, raw1_fixed)
;
;print, "Make_Sky True is Done !"
end