pro P12_Load_Flat_List, Event
	;
	;	read the Dark directory to get the image list,
	;	then read each header to get the exposure time and UT
	;	for each image into the BDF summary structure
	;
	MSP_BDP_print_text, Event, "Fetch Flat List Requested"
	;
	WIDGET_CONTROL, Event.top, GET_UVALUE=PTR_struct
	n_ptr = PTR_struct.PTR_night
	s_ptr = PTR_struct.PTR_summary
	f_ptr = PTR_struct.PTR_FITS
	b_ptr = PTR_struct.PTR_BPM
	bdf_ptr = PTR_struct.PTR_BDF
	ff_ptr = PTR_struct.PTR_Flat
	;
	;	first, build the directory path to search
	;
	root_reduced = (*s_ptr).root_reduced
	;
	flat_directory = '10_Flat_Field_Images'
	;
	flat_dir_path = root_reduced + flat_directory + PATH_SEP()
	;
	;print, "flat_path = ",flat_dir_path
	;
	;	get list of images in that directory
	;
	test_dir = FILE_INFO(flat_dir_path)
	if( NOT(test_dir.exists) or NOT(test_dir.directory) ) then begin
		MSP_BDP_print_text, Event, "ERROR - Flat Field directory path incorrect"
		(*bdf_ptr).n_flat = 0L
		goto, MBPBH_end
	endif
	;
	flat_list = FILE_SEARCH(flat_dir_path+'*.fits')
	;
	;print, "flat_list = ",flat_list
	;
	n_flat = N_ELEMENTS(flat_list)
	;
	MSP_BDP_print_text, Event, "Found "+STRING(format='(I)',n_flat)+" Flat Field images."
	;
	;	parse into pol and non-pol flats
	;
	ind_pol = WHERE((STRPOS(STRUPCASE(flat_list[*]),'-POL') ne -1),n_pol_flat)
	ind_non_pol = WHERE((STRPOS(STRUPCASE(flat_list[*]),'-POL') eq -1),n_non_pol_flat)
	;
	if(n_pol_flat ge 1) then begin
		pol_flat_list = flat_list[ind_pol]
	endif
	;
	if(n_non_pol_flat ge 1) then begin
		flat_list = flat_list[ind_non_pol]
		n_flat = n_non_pol_flat
	endif
	;----------------------- collect the non-pol flats first ----------------------
	;
	;	open each and build the type, filter, camera, expt, date, UT, path list
	;
	(*bdf_ptr).n_flat = n_flat
	;
	if(n_flat gt 0) then begin
		for iflat = 0, n_flat-1 do begin
			flat_path = flat_list[iflat]
			(*bdf_ptr).flat_path[iflat] = flat_path
			;
			;	read the flat field image
			;
			header_flat = headfits(flat_path, /silent)
			filename = FILE_BASENAME(flat_path)
			;
;			print, "Filename = ",filename
			;
			;	load buffers
			;
			n_header_lines = N_ELEMENTS(header_flat)
			(*s_ptr).raw_header[0:n_header_lines-1] = header_flat
			(*s_ptr).raw_header[n_header_lines:N_ELEMENTS((*s_ptr).raw_header)-1] = ''
			;
			;	extract key values
			;
			MSP_BDP_Parse_FITS_Header, Event
			;
			(*bdf_ptr).flat_ut[iflat] = (*f_ptr).ut
			;
			(*bdf_ptr).flat_exptime[iflat] = (*f_ptr).exptime
			;
			;	evaluate type, camera, filter
			;
			MSP_BDP_Camera_Classify, Event, camera_summary_name
			MSP_BDP_Filter_Classify, Event, camera_summary_name, filter_summary_name
			;
			MSP_BDP_Observation_Classify, Event, filter_summary_name, observation_summary_name
			;
			;MSP_BDP_Camera_Classify, Event, camera_summary_name
			;
			;	check classifications against file name
			;
			up_filename = STRUPCASE(filename)
			;
;			print, "up_filename = ",up_filename
			;
			xtest_F5 = STRPOS(up_filename,"_F5_") ne -1
			xtest_F17 = STRPOS(up_filename,"_F17_") ne -1
			xtest_JHKSpec = STRPOS(up_filename,"_JHK-SPEC") ne -1
			xtest_HImg = STRPOS(up_filename,"_H-IMG_") ne -1
			xtest_KImg = STRPOS(up_filename,"_K-IMG_") ne -1
			xtest_JImg = STRPOS(up_filename,"_J-IMG_") ne -1
			xtest_H2OnImg = STRPOS(up_filename,"_H2ON-IMG_") ne -1
			xtest_H2OffImg = STRPOS(up_filename,"_H2OFF-IMG_") ne -1
			xtest_KSpec = STRPOS(up_filename,"_K-SPEC_") ne -1
			xtest_JSpec = STRPOS(up_filename,"_J-SPEC_") ne -1
			;
			if(xtest_F5 and camera_summary_name ne 'F5') then camera_summary_name = 'F5'
			if(xtest_F17 and camera_summary_name ne 'F17') then camera_summary_name = 'F17'
			;
;			print, "Xtest: F5, F17, JHKSpec, HImg, KImg, JImg, H2OnImg, H2OffImg, KSpec, JSpec = ",$
;				xtest_F5, xtest_F17, xtest_JHKSpec, xtest_HImg, xtest_KImg, xtest_JImg, xtest_H2OnImg, $
;				xtest_H2OffImg, xtest_KSpec, xtest_JSpec
			;
			if(xtest_JHKSpec) then begin
				observation_summary_name = 'S-Flat'
				filter_name = 'JHK-Spec'
			endif
			if(xtest_KSpec) then begin
				observation_summary_name = 'S-Flat'
				filter_name = 'K-Spec'
			endif
			if(xtest_JSpec) then begin
				observation_summary_name = 'S-Flat'
				filter_name = 'J-Spec'
			endif
			if(xtest_JImg) then begin
				observation_summary_name = 'I-Flat'
				filter_name = 'J-Img'
			endif
			if(xtest_HImg) then begin
				observation_summary_name = 'I-Flat'
				filter_name = 'H-Img'
			endif
			if(xtest_KImg) then begin
				observation_summary_name = 'I-Flat'
				filter_name = 'K-Img'
			endif
			if(xtest_H2OnImg) then begin
				observation_summary_name = 'I-Flat'
				filter_name = 'H2On-Img'
			endif
			if(xtest_H2OffImg) then begin
				observation_summary_name = 'I-Flat'
				filter_name = 'H2Off-Img'
			endif
			;
			(*bdf_ptr).flat_type[iflat] = observation_summary_name
			(*bdf_ptr).flat_camera[iflat] = camera_summary_name
			(*bdf_ptr).flat_filter[iflat] = filter_summary_name
			;
			;object = (*f_ptr).object
			;comment1 = (*f_ptr).comment[0]
			;comment2 = (*f_ptr).comment[1]
			;occ = object + ' ' + comment1 + ' ' + comment2
			;print, "object+comment1+comment2 = ",occ
			;print, "returned camera name = ",camera_summary_name
			;
			date_obs = (*f_ptr).date_obs
			year = 0L
			month = 0L
			day = 0L
			reads, date_obs, format='(I4,1x,i2,1x,i2)',year, month, day
			night_desig = year * 10000L + month * 100L + day
			;
			flat_UT = (*bdf_ptr).flat_ut[iflat]
			hour = FLOOR(flat_UT)
			minute = FLOOR((flat_UT - double(hour))*60.0d0)
			second = 3600.0d0 * (flat_UT - double(hour) - double(minute)/60.0d0)
			;
			flat_jd = JULDAY(month, day, year, hour, minute, ROUND(second))
			;
			(*bdf_ptr).flat_jd[iflat] = flat_jd
			;
;			print, "Flat No. ",iflat," Obs_type = ",(*bdf_ptr).flat_type[iflat], " Filter = ",(*bdf_ptr).flat_filter[iflat], $
;					" Camera = ",(*bdf_ptr).flat_camera[iflat], " Night, UT = ",night_desig,' ', (*bdf_ptr).flat_UT[iflat], $
;					" path = ",(*bdf_ptr).flat_path[iflat]
		endfor
		MSP_BDP_print_text, Event, "Read "+STRING(format='(I)',n_flat)+" photometric and spectroscopic flats"
	endif
	;
	;--------------------------- and the pol flats next ---------------------------
	;
	;	open each and build the type, filter, camera, expt, date, UT, path list
	;
	(*bdf_ptr).n_polar_flat = n_pol_flat
	;
	if(n_pol_flat gt 0) then begin
		for iflat = 0, n_pol_flat-1 do begin
			polar_flat_path = pol_flat_list[iflat]
			(*bdf_ptr).polar_flat_path[iflat] = polar_flat_path
			;
			;	read the flat field image
			;
			header_flat = headfits(polar_flat_path, /silent)
			polar_filename = FILE_BASENAME(polar_flat_path)
			up_filename = STRUPCASE(polar_filename)
			;
			;	load buffers
			;
			n_header_lines = N_ELEMENTS(header_flat)
			(*s_ptr).raw_header[0:n_header_lines-1] = header_flat
			(*s_ptr).raw_header[n_header_lines:N_ELEMENTS((*s_ptr).raw_header)-1] = ''
			;
			;	extract key values
			;
			MSP_BDP_Parse_FITS_Header, Event
			;
			(*bdf_ptr).polar_flat_ut[iflat] = (*f_ptr).ut
			;
			;	evaluate type, camera, filter
			;
			MSP_BDP_Camera_Classify, Event, camera_summary_name
			MSP_BDP_Filter_Classify, Event, camera_summary_name, filter_summary_name
			(*bdf_ptr).polar_flat_filter[iflat] = filter_summary_name
			;
			MSP_BDP_Observation_Classify, Event, filter_summary_name, observation_summary_name
			;
			;MSP_BDP_Camera_Classify, Event, camera_summary_name
			;
			;	and HWP angle
			;
			MSP_BDP_Parse_HWP_Angle, Event, HWP_angle
			(*bdf_ptr).polar_flat_HWP[iflat] = HWP_angle
			;
			;	check classifications against file name
			;
			xtest_F5 = STRPOS(up_filename,"_F5_") ne -1
			xtest_F17 = STRPOS(up_filename,"_F17_") ne -1
			;
			if(xtest_F5) then camera_summary_name = 'F5'
			if(xtest_F17) then camera_summary_name = 'F17'
			;
			(*bdf_ptr).polar_flat_type[iflat] = observation_summary_name
			(*bdf_ptr).polar_flat_camera[iflat] = camera_summary_name
			;
			;
			;object = (*f_ptr).object
			;comment1 = (*f_ptr).comment[0]
			;comment2 = (*f_ptr).comment[1]
			;occ = object + ' ' + comment1 + ' ' + comment2
			;print, "object+comment1+comment2 = ",occ
			;print, "returned camera name = ",camera_summary_name
			;
			date_obs = (*f_ptr).date_obs
			year = 0L
			month = 0L
			day = 0L
			reads, date_obs, format='(I4,1x,i2,1x,i2)',year, month, day
			night_desig = year * 10000L + month * 100L + day
			;
;			flat_UT = (*bdf_ptr).flat_ut[iflat]
;			hour = FLOOR(flat_UT)
;			minute = FLOOR((flat_UT - double(hour))*60.0d0)
;			second = 3600.0d0 * (flat_UT - double(hour) - double(minute)/60.0d0)
			;
			;	reset HH, MM, DD since they don't make sense in coadded images
			;
			if(camera_summary_name eq 'F5') then hour = 9 else hour = 0
			minute = 0
			second = 0
			;
			flat_jd = JULDAY(month, day, year, hour, minute, ROUND(second))
			;
			(*bdf_ptr).polar_flat_jd[iflat] = flat_jd

			;
;			print, "Flat No. ",iflat," Obs_type = ",observation_summary_name, " Filter = ",filter_summary_name, $
;					" Camera = ",camera_summary_name, " Night, UT = ",night_desig, (*bdf_ptr).flat_UT[iflat], $
;					" path = ",flat_path
;			print, "HWP = ",HWP_angle
			;
		endfor
		MSP_BDP_print_text, Event, "Read "+STRING(format='(I)',n_pol_flat)+" polarimetric flats"
		;
		;	sort by filter and then JD to separate different polar sets
		;
		n_polar_sets = CEIL(n_pol_flat / 16)	; number of distinct polar sets
		;
		;	number of filters present
		;
		ind_j_pol = WHERE( (*bdf_ptr).polar_flat_filter[0:n_pol_flat-1] eq 'J-Pol', n_j_pol)
		ind_h_pol = WHERE( (*bdf_ptr).polar_flat_filter[0:n_pol_flat-1] eq 'H-Pol', n_h_pol)
		ind_k_pol = WHERE( (*bdf_ptr).polar_flat_filter[0:n_pol_flat-1] eq 'K-Pol', n_k_pol)
		ind_l_pol = WHERE( (*bdf_ptr).polar_flat_filter[0:n_pol_flat-1] eq 'L-Pol', n_l_pol)
		ind_m_pol = WHERE( (*bdf_ptr).polar_flat_filter[0:n_pol_flat-1] eq 'M-Pol', n_m_pol)
		;
		n_j_sets = CEIL(n_j_pol / 16)
		n_h_sets = CEIL(n_h_pol / 16)
		n_k_sets = CEIL(n_k_pol / 16)
		n_l_sets = CEIL(n_l_pol / 16)
		n_m_sets = CEIL(n_m_pol / 16)
		;
		n_filt_sets = (n_j_sets < 1) + (n_h_sets < 1) + (n_k_sets < 1) + (n_l_sets < 1) + (n_m_sets < 1)
		n_polar_sets = n_j_sets + n_h_sets + n_k_sets + n_l_sets + n_m_sets
		;
		MSP_BDP_print_text, Event, 'Found a total of '+STRING(n_filt_sets,format='(I)')+' different pol filters'
		if(n_j_sets gt 0) then MSP_BDP_print_text, Event,' number of J-Pol Flat sets = '+STRING(n_j_sets,format='(I)')
		if(n_h_sets gt 0) then MSP_BDP_print_text, Event,' number of H-Pol Flat sets = '+STRING(n_h_sets,format='(I)')
		if(n_k_sets gt 0) then MSP_BDP_print_text, Event,' number of K-Pol Flat sets = '+STRING(n_k_sets,format='(I)')
		if(n_l_sets gt 0) then MSP_BDP_print_text, Event,' number of L-Pol Flat sets = '+STRING(n_l_sets,format='(I)')
		if(n_m_sets gt 0) then MSP_BDP_print_text, Event,' number of M-Pol Flat sets = '+STRING(n_m_sets,format='(I)')
		;
		;	sets to be organized by filter, then subset number (using JD)
		;
		i_set = 0
		i_sort = 0
		all_sort_ind = lonarr(n_pol_flat)				; roll up of all indices from sets to raw
		;
		if(n_j_sets gt 0) then begin
			;
			;	J-Pol flats present. How many JDs? Which ones?
			;
			sort_ind = SORT( (*bdf_ptr).polar_flat_jd[ind_j_pol] )		; grab all the indices to the J-pol flats
			jd_ind = UNIQ( (*bdf_ptr).polar_flat_jd[ind_j_pol[sort_ind]] )
			n_j_jd = N_ELEMENTS(jd_ind)
			;
			;	save the JD sorted list to the all-sort-list
			;
			all_sort_ind[i_sort: i_sort + n_j_pol-1] = ind_j_pol[sort_ind]
			i_sort += n_j_pol
			;
			for ij = 0, n_j_jd-1 do begin
				;
				;	number in this JD group
				;
				jjd_ind = WHERE( (*bdf_ptr).polar_flat_jd[ind_j_pol[sort_ind]] eq $
								 (*bdf_ptr).polar_flat_jd[ind_j_pol[sort_ind[jd_ind[ij]]]], njd)
				(*bdf_ptr).polar_flat_set_elements[i_set] = njd
				;
				(*bdf_ptr).polar_flat_set_filter[i_set] = 'J-Pol'
				(*bdf_ptr).polar_flat_set_jd[i_set] = (*bdf_ptr).polar_flat_jd[ind_j_pol[sort_ind[jd_ind[ij]]]]
				i_set++
				;
				MSP_BDP_print_text, Event, 'Polar Flat Set '+STRING(i_set,format='(I)')+' :'
				MSP_BDP_print_text, Event, '   Filter = '+(*bdf_ptr).polar_flat_set_filter[i_set-1]
				MSP_BDP_print_text, Event, '   JD     = '+STRING( (*bdf_ptr).polar_flat_set_jd[i_set-1],$
										format='(I)')
			endfor
		endif
		;
		if(n_h_sets gt 0) then begin
			;
			;	H-Pol flats present. How many JDs? Which ones?
			;
			sort_ind = SORT( (*bdf_ptr).polar_flat_jd[ind_h_pol] )		; grab all the indices to the H-pol flats
			jd_ind = UNIQ( (*bdf_ptr).polar_flat_jd[ind_h_pol[sort_ind]] )
			n_h_jd = N_ELEMENTS(jd_ind)
			;
			;	save the JD sorted list to the all-sort-list
			;
			all_sort_ind[i_sort: i_sort + n_h_pol-1] = ind_h_pol[sort_ind]
			i_sort += n_h_pol
			;
			for ij = 0, n_h_jd-1 do begin
				;
				;	number in this JD group
				;
				jjd_ind = WHERE( (*bdf_ptr).polar_flat_jd[ind_h_pol[sort_ind]] eq $
								 (*bdf_ptr).polar_flat_jd[ind_h_pol[sort_ind[jd_ind[ij]]]], njd)
				(*bdf_ptr).polar_flat_set_elements[i_set] = njd
				;
				(*bdf_ptr).polar_flat_set_filter[i_set] = 'H-Pol'
				(*bdf_ptr).polar_flat_set_jd[i_set] = (*bdf_ptr).polar_flat_jd[ind_h_pol[sort_ind[jd_ind[ij]]]]
				i_set++
				;
				MSP_BDP_print_text, Event, 'Polar Flat Set '+STRING(i_set,format='(I)')+' :'
				MSP_BDP_print_text, Event, '   Filter = '+(*bdf_ptr).polar_flat_set_filter[i_set-1]
				MSP_BDP_print_text, Event, '   JD     = '+STRING( (*bdf_ptr).polar_flat_set_jd[i_set-1],$
										format='(I)')
			endfor
		endif
		;
		if(n_k_sets gt 0) then begin
			;
			;	K-Pol flats present. How many JDs? Which ones?
			;
			sort_ind = SORT( (*bdf_ptr).polar_flat_jd[ind_k_pol] )		; grab all the indices to the K-pol flats
			jd_ind = UNIQ( (*bdf_ptr).polar_flat_jd[ind_k_pol[sort_ind]] )
			n_k_jd = N_ELEMENTS(jd_ind)
			;
			;	save the JD sorted list to the all-sort-list
			;
			all_sort_ind[i_sort: i_sort + n_k_pol-1] = ind_k_pol[sort_ind]
			i_sort += n_k_pol
			;
			for ij = 0, n_k_jd-1 do begin
				;
				;	number in this JD group
				;
				jjd_ind = WHERE( (*bdf_ptr).polar_flat_jd[ind_k_pol[sort_ind]] eq $
								 (*bdf_ptr).polar_flat_jd[ind_k_pol[sort_ind[jd_ind[ij]]]], njd)
				(*bdf_ptr).polar_flat_set_elements[i_set] = njd
				;
				(*bdf_ptr).polar_flat_set_filter[i_set] = 'K-Pol'
				(*bdf_ptr).polar_flat_set_jd[i_set] = (*bdf_ptr).polar_flat_jd[ind_k_pol[sort_ind[jd_ind[ij]]]]
				i_set++
				;
				MSP_BDP_print_text, Event, 'Polar Flat Set '+STRING(i_set,format='(I)')+' :'
				MSP_BDP_print_text, Event, '   Filter = '+(*bdf_ptr).polar_flat_set_filter[i_set-1]
				MSP_BDP_print_text, Event, '   JD     = '+STRING( (*bdf_ptr).polar_flat_set_jd[i_set-1],$
										format='(I)')
			endfor
		endif
		;
		if(n_l_sets gt 0) then begin
			;
			;	L-Pol flats present. How many JDs? Which ones?
			;
			sort_ind = SORT( (*bdf_ptr).polar_flat_jd[ind_l_pol] )		; grab all the indices to the L-pol flats
			jd_ind = UNIQ( (*bdf_ptr).polar_flat_jd[ind_l_pol[sort_ind]] )
			n_l_jd = N_ELEMENTS(jd_ind)
			;
			;	save the JD sorted list to the all-sort-list
			;
			all_sort_ind[i_sort: i_sort + n_l_pol-1] = ind_l_pol[sort_ind]
			i_sort += n_l_pol
			;
			for ij = 0, n_l_jd-1 do begin
				;
				;	number in this JD group
				;
				jjd_ind = WHERE( (*bdf_ptr).polar_flat_jd[ind_L_pol[sort_ind]] eq $
								 (*bdf_ptr).polar_flat_jd[ind_L_pol[sort_ind[jd_ind[ij]]]], njd)
				(*bdf_ptr).polar_flat_set_elements[i_set] = njd
				;
				(*bdf_ptr).polar_flat_set_filter[i_set] = 'L-Pol'
				(*bdf_ptr).polar_flat_set_jd[i_set] = (*bdf_ptr).polar_flat_jd[ind_l_pol[sort_ind[jd_ind[ij]]]]
				i_set++
				;
				MSP_BDP_print_text, Event, 'Polar Flat Set '+STRING(i_set,format='(I)')+' :'
				MSP_BDP_print_text, Event, '   Filter = '+(*bdf_ptr).polar_flat_set_filter[i_set-1]
				MSP_BDP_print_text, Event, '   JD     = '+STRING( (*bdf_ptr).polar_flat_set_jd[i_set-1],$
										format='(I)')
			endfor
		endif
		;
		if(n_m_sets gt 0) then begin
			;
			;	M-Pol flats present. How many JDs? Which ones?
			;
			sort_ind = SORT( (*bdf_ptr).polar_flat_jd[ind_m_pol] )		; grab all the indices to the M-pol flats
			jd_ind = UNIQ( (*bdf_ptr).polar_flat_jd[ind_m_pol[sort_ind]] )
			n_m_jd = N_ELEMENTS(jd_ind)
			;
			;	save the JD sorted list to the all-sort-list
			;
			all_sort_ind[i_sort: i_sort + n_m_pol-1] = ind_m_pol[sort_ind]
			i_sort += n_m_pol
			;
			for ij = 0, n_m_jd-1 do begin
				;
				;	number in this JD group
				;
				jjd_ind = WHERE( (*bdf_ptr).polar_flat_jd[ind_m_pol[sort_ind]] eq $
								 (*bdf_ptr).polar_flat_jd[ind_m_pol[sort_ind[jd_ind[ij]]]], njd)
				(*bdf_ptr).polar_flat_set_elements[i_set] = njd
				;
				(*bdf_ptr).polar_flat_set_filter[i_set] = 'M-Pol'
				(*bdf_ptr).polar_flat_set_jd[i_set] = (*bdf_ptr).polar_flat_jd[ind_m_pol[sort_ind[jd_ind[ij]]]]
				i_set++
				;
				MSP_BDP_print_text, Event, 'Polar Flat Set '+STRING(i_set,format='(I)')+' :'
				MSP_BDP_print_text, Event, '   Filter = '+(*bdf_ptr).polar_flat_set_filter[i_set-1]
				MSP_BDP_print_text, Event, '   JD     = '+STRING( (*bdf_ptr).polar_flat_set_jd[i_set-1],$
										format='(I)')
			endfor
		endif
		;
		(*bdf_ptr).n_polar_flat_sets = i_set
		;
		;	now, have all sets accounted for, need to resort everyone with new global indices
		;
		(*bdf_ptr).polar_flat_path[0:i_sort-1] = (*bdf_ptr).polar_flat_path[all_sort_ind[0:i_sort-1]]
		(*bdf_ptr).polar_flat_ut[0:i_sort-1] = (*bdf_ptr).polar_flat_ut[all_sort_ind[0:i_sort-1]]
		(*bdf_ptr).polar_flat_filter[0:i_sort-1] = (*bdf_ptr).polar_flat_filter[all_sort_ind[0:i_sort-1]]
		(*bdf_ptr).polar_flat_type[0:i_sort-1] = (*bdf_ptr).polar_flat_type[all_sort_ind[0:i_sort-1]]
		(*bdf_ptr).polar_flat_camera[0:i_sort-1] = (*bdf_ptr).polar_flat_camera[all_sort_ind[0:i_sort-1]]
		(*bdf_ptr).polar_flat_HWP[0:i_sort-1] = (*bdf_ptr).polar_flat_HWP[all_sort_ind[0:i_sort-1]]
		(*bdf_ptr).polar_flat_jd[0:i_sort-1] = (*bdf_ptr).polar_flat_jd[all_sort_ind[0:i_sort-1]]
		;
		;	order is now: (J-pol, night 1), (J-Pol, night 2), (H-pol, night 1), etc
		;
		;	organize by HWP within each set
		;
		for i_set = 0, n_polar_sets-1 do begin
			;
			if(i_set ne 0) then begin
				i_off = FIX(TOTAL( (*bdf_ptr).polar_flat_set_elements[0:i_set-1] ),TYPE=3)
			endif else begin
				i_off = 0L
			endelse
			;
			;	recover the indices to this set
			;
			this_ind = indgen( (*bdf_ptr).polar_flat_set_elements[i_set]) + i_off
			;
			;	sort this set by HWP angle
			;
			sort_ind = SORT( (*bdf_ptr).polar_flat_HWP[this_ind] )
			i_min = MIN(this_ind)
			i_max = MAX(this_ind)
			;
			(*bdf_ptr).polar_flat_path[i_min:i_max] = (*bdf_ptr).polar_flat_path[this_ind[sort_ind]]
			(*bdf_ptr).polar_flat_ut[i_min:i_max] = (*bdf_ptr).polar_flat_ut[this_ind[sort_ind]]
			(*bdf_ptr).polar_flat_filter[i_min:i_max] = (*bdf_ptr).polar_flat_filter[this_ind[sort_ind]]
			(*bdf_ptr).polar_flat_type[i_min:i_max] = (*bdf_ptr).polar_flat_type[this_ind[sort_ind]]
			(*bdf_ptr).polar_flat_camera[i_min:i_max] = (*bdf_ptr).polar_flat_camera[this_ind[sort_ind]]
			(*bdf_ptr).polar_flat_HWP[i_min:i_max] = (*bdf_ptr).polar_flat_HWP[this_ind[sort_ind]]
			(*bdf_ptr).polar_flat_jd[i_min:i_max] = (*bdf_ptr).polar_flat_jd[this_ind[sort_ind]]
		endfor
		;
		;	how many instances of HWP=0 are there?
		;
		hwp_0_ind = WHERE( (*bdf_ptr).polar_flat_HWP[0:n_pol_flat-1] eq 0.00, count_hwp_0)
		if(count_hwp_0 le 0) then begin
			MSP_BDP_print_text, Event, "Error - found no HWP=0 cases in polar flats.. Uh oh.."
			(*bdf_ptr).n_polar_flat_sets = 0
			goto, MBPBH_end
		endif
		;
		;
		;stop
		;
		;	determine how many polar images per flat set (not necessarily identical)
		;
		for i_p_set = 0, (*bdf_ptr).n_polar_flat_sets-1 do begin
			MSP_BDP_print_text, Event, "For Polar Flat Set "+STRING(format='(I)',i_p_set+1)+ $
									' found '+STRING(format='(I)',(*bdf_ptr).polar_flat_set_elements[i_p_set])+$
									' constituent flat images'
			;
			;	load the pol FF name root and the mean PA
			;
			if(i_p_set gt 0) then begin
				ff_root_number = FIX(TOTAL( (*bdf_ptr).polar_flat_set_elements[0:i_p_set - 1] ),TYPE=3)	; pointer to first pol flat in group
			endif else begin
				ff_root_number = 0L
			endelse
			;
			this_polar_path = (*bdf_ptr).polar_flat_path[ff_root_number]
			;
			this_polar_night = STRMID(FILE_BASENAME(this_polar_path), 4,8)
			;
			this_polar_filter = (*bdf_ptr).polar_flat_filter[ff_root_number]
			;
			ff_dir = FILE_DIRNAME(this_polar_path)
			;
			;	build pathname to mean_PA file
			;
			ff_path = ff_dir + PATH_SEP() + this_polar_filter + '_FF_'+this_polar_night+'_mean_PA.dat'
			;
			f_test = FILE_INFO(ff_path)
			if(f_test.exists) then begin
				openr, lu_pa, ff_path, /GET_LUN
				line = ''
				WHILE ~EOF(lu_pa) do begin
					readf, lu_pa, line
					indx = STRPOS(line, ';')
					if(indx eq -1) then begin		; no semicolon
						last = STRPOS(line,'/')
						short_line = STRMID(line, 9, (last-9))
						reads, short_line, mean_PA
						(*bdf_ptr).polar_flat_mean_PA[i_p_set] = mean_PA
						;
						MSP_BDP_print_text, Event, "Loaded mean_PA of "+STRING(mean_PA)+" for Pol FF group "+STRING(i_p_set)+" "+this_polar_night
					endif
				ENDWHILE
				FREE_LUN, lu_pa
			endif else begin
				MSP_BDP_print_text, Event, "ERROR - did not find mean_PA file "+ff_path+" in pol ff directory"
;				stop
				goto, MBPBH_end
			endelse
		endfor
	endif
	;
	MBPBH_end:
end
