;----------------------------------------------------------------------
pro P2_Build_A_Group, Event, g_ptr
	WIDGET_CONTROL, Event.top, GET_UVALUE=PTR_struct
	s_ptr = PTR_struct.PTR_summary
	n_ptr = PTR_struct.PTR_night
	;
	;	from characteristics of the first image in the group,
	;	build the group information
	;
	start_image = (*g_ptr).start_image		; image id number, not order in arrays
	group_number = (*g_ptr).group_no - 1
	start_index = (*g_ptr).image_index		; order in array, not image scan number
	n_images = (*g_ptr).n_images
	;
	object = (*n_ptr).image_object[start_index]
	(*n_ptr).groups[group_number].group_object = object
	image_type = (*n_ptr).image_type[start_index]
	(*n_ptr).groups[group_number].group_type = image_type
	filter = (*n_ptr).image_filter[start_index]
	(*n_ptr).groups[group_number].group_filter = filter
	exptime = (*n_ptr).image_exptime[start_index]
	(*n_ptr).groups[group_number].group_exptime = exptime
	frame = (*n_ptr).image_frame[start_index]
	(*n_ptr).groups[group_number].group_frame = frame
	read_mode = (*n_ptr).image_readout_mode[start_index]
	(*n_ptr).groups[group_number].group_readout_mode = read_mode
	camera = (*n_ptr).image_camera[start_index]
	(*n_ptr).groups[group_number].group_camera = camera
	;
	(*n_ptr).groups[group_number].group_id = group_number
	group_count = 1
	(*n_ptr).groups[group_number].group_images = group_count
	(*n_ptr).groups[group_number].group_list[0] = start_image
	(*n_ptr).groups[group_number].group_end = start_image
	;
	coadds = (*n_ptr).image_coadds[start_index]
	(*n_ptr).groups[group_number].group_coadds = coadds
	;
	;	look down the list
	;
	last_UT = (*n_ptr).header_list[start_index].ut	; in hours
	last_expt = exptime								; in sec
	;
	for image_index = start_index+1, (*n_ptr).num_images-1 do begin		; from next to end
		;
		;	if this image already has a group assigned, skip it
		;
		if( (*g_ptr).image_group_list[1,image_index] eq 0) then begin
			;
			;	if this next image has a different object name, frame format, read mode, or camera then exit
			;
			;	20080101 - also, if the ut difference from the most recent addition to the one
			;				being considered differs by more than the exposure time plus 1 minute, exit
			;				(this to prevent merging distinct bias groups, mainly).
			;
			this_object = (*n_ptr).image_object[image_index]
			this_frame = (*n_ptr).image_frame[image_index]
			this_read_mode = (*n_ptr).image_readout_mode[image_index]
			this_camera = (*n_ptr).image_camera[image_index]
			;
			;	get UT for this image
			;
			this_UT = (*n_ptr).header_list[image_index].ut
			;
			if(this_object ne object) then goto, loop_end
			if(this_frame ne frame) then goto, loop_end
			if(this_read_mode ne read_mode) then goto, loop_end
			if(this_camera ne camera) then goto, loop_end
			;
			;	OK, passes all these, fetch other info
			;
			this_type = (*n_ptr).image_type[image_index]
			this_filter = (*n_ptr).image_filter[image_index]
			this_exptime = (*n_ptr).image_exptime[image_index]
			;
			if(this_exptime eq exptime) then e_test = 1 else e_test = 0
			if(this_filter eq filter) then f_test = 1 else f_test = 0
			if(this_type eq image_type) then t_test = 1 else t_test = 0
			;
			;	now, inclusion or rejection of images depends on the type of observation
			;	as does the declaration of the end of the group or not
			;
			this_save = 0
			;
			case this_type of
				"Lin-On": if(f_test eq 0) then goto, loop_end else this_save = 1
				"Lin-Off": if(f_test eq 0) then goto, loop_end else this_save = 1
				"Image": if(e_test eq 0 and f_test eq 1) then goto, loop_end else if(f_test eq 1) then this_save = 1
				else:	if(e_test+f_test+t_test lt 3) then goto, loop_end else this_save = 1
			endcase
			;
			;	check that difference UT is less than last exposure time plus one minute
			;	for all but "Image" types - "Image" type might be dithered
			;
			if(this_type ne 'Image') then begin
				d_ut = (this_UT - last_UT)
				d_time = 3600.0 * d_ut
				extra_time = d_time - last_expt
				if(extra_time gt 60.0) then begin
					;print, "This, Last UTs = ",this_UT, last_UT
					;print, "dUT [s], exptime = ",d_time, last_expt
					;print, "extra_time [s] = ",extra_time
					MSP_BDP_print_text, Event, "Cleaving Group "+STRING(format='(I5.1)',group_number)+' from next group'
					goto, loop_end
				endif
			endif
			;
			;	ok, now what to do? if this_save =0, skip this image and go onto next
			;
			if(this_save eq 1) then begin
				;
				;	this image is part of the current group, add its image number to the list,
				;	set its group number flag, and bump the image counter for the group
				;
				(*g_ptr).image_group_list[1,image_index] = group_number + 1
				group_count++
				(*n_ptr).groups[group_number].group_images=group_count
				(*n_ptr).groups[group_number].group_list[group_count-1] = (*g_ptr).image_group_list[0,image_index]
				(*n_ptr).groups[group_number].group_end = (*g_ptr).image_group_list[0,image_index]
				;
				last_UT = this_UT
				last_expt = this_exptime
			endif
			;
			;
		endif				; end of test for image already grouped
	endfor
	;
	loop_end:				; come here if we need to close the group
end