pro coadd_median_with_bad_RAW1_sub_new, Event, bpf, pathlist, outpath, $
									row513_flag, LED_wid, this_LED, colors, $
									NO_OUTPUT=no_output, COADDS=coadds
	;
	;   adds (averages) Mimir images, from list of file pathnames supplied
	;   using a median filter for each pixel, rejecting
	;   outliers, if possible
	;
	;   this version does the RAW1 images
	;
	;   DPC 20050611 modified from coadd_median_with_bad.pro to work as a subroutine
	;		20100120 rewritten for speed
	;		20130920 added coadds correction on input
	;
	;-----------------------------------------
	;
	WIDGET_CONTROL, Event.top, GET_UVALUE=PTR_struct
	s_ptr = PTR_struct.PTR_summary
	l_ptr = PTR_struct.PTR_Linearity
	;
	;	check status of no_output switch
	;
	if(KEYWORD_SET(no_output)) then NO_OUTPUT=1 else NO_OUTPUT=0
	if(N_ELEMENTS(COADDS) ne 0) then this_coadds = coadds else this_coadds = 1
	;
	image = read_raw1(pathlist[0])
	;
	if(this_coadds ne 1) then image /= this_coadds
	;
	i_size = SIZE(image)
	ncol = i_size[1]
	nrow = i_size[2]
	nimage = N_ELEMENTS(pathlist)
	;
	good_mask_ptr 	= PTR_NEW(fltarr(ncol,nrow))
	big_good_mask_ptr = PTR_NEW(fltarr(nimage,ncol,nrow))
	image_data_ptr 	= PTR_NEW(lonarr(nimage,ncol,nrow))
	image_mask_ptr 	= PTR_NEW(fltarr(nimage,ncol,nrow))
	image_count_ptr = PTR_NEW(fltarr(ncol,nrow))
	accum_ptr 		= PTR_NEW(dblarr(ncol,nrow))
	square_ptr 		= PTR_NEW(dblarr(ncol,nrow))
	sigma_ptr 		= PTR_NEW(dblarr(ncol,nrow))
	accum_mask_ptr 	= PTR_NEW(intarr(ncol,nrow))
	median_ptr		= PTR_NEW(fltarr(ncol,nrow))
	median_mask_ptr = PTR_NEW(fltarr(nimage,ncol,nrow))
	product_data_mask_ptr = PTR_NEW(lonarr(nimage,ncol,nrow))
	;
	;   load the bad pixel mask as a good pixel mask
	;
	(*good_mask_ptr) = readfits(bpf,header,/silent)
	(*good_mask_ptr) *= -1.0
	(*good_mask_ptr) += 1.0			; 1 - bpm = goodmask
	;
	for ifile = 0, nimage-1 do (*big_good_mask_ptr)[ifile,*,*] = (*good_mask_ptr)
	;
	;   read in each file into big arrays, using pointers
	;
	(*image_data_ptr)[0,*,*] = image
	;
	if(nimage gt 0) then begin
		for ifile = 1, nimage-1 do begin
			(*image_data_ptr)[ifile,*,*] = read_raw1(pathlist[ifile])
			;
			if(this_coadds ne 1) then (*image_data_ptr)[ifile,*,*] /= this_coadds
		endfor
	endif
	;
	colors[this_LED] = 'orange'
	WCT_LED_stack, LED_wid, colors
	MSP_BDP_print_text, Event, "Read "+STRING(format='(i)',nimage)+" input RAW1 images"
	;
	;   the pixel evaluation and combining engine
	;
	icolor = 'blue'
	;
	;	calculate image mask
	;
	(*image_mask_ptr) = ((*image_data_ptr) < 1.0) > 0.0				; 0 for 0 data or neg, 1 for good
	;
	;	for 3 passes, reject values more than 5 sigma out
	;
	scale_step = [2.5, 3.5, 5.0]
	;
	for ipass = 0, 2 do begin
		;
		this_scale = scale_step[ipass]
		;
		colors[this_LED] = icolor
		WCT_LED_stack, LED_wid, colors
		if(icolor eq 'blue') then icolor = 'orange' else icolor = 'blue'
		;
		;	and include the bad pixel mask
		;
		(*image_mask_ptr) *= (*big_good_mask_ptr)  ; mask with the bpm
		;
		;	compute mean
		;
		(*product_data_mask_ptr) = (*image_data_ptr)
		(*product_data_mask_ptr) *= (*image_mask_ptr)
		;
		(*accum_ptr) 		= TOTAL( (*product_data_mask_ptr) ,1,/DOUBLE)
		(*image_count_ptr) 	= TOTAL( (*image_mask_ptr) ,1,/DOUBLE)
		(*accum_ptr) 		/=  (*image_count_ptr) 							; average, with divide by zero giving NaNs
		;
		(*square_ptr) 		= TOTAL( (*image_data_ptr) * (*product_data_mask_ptr) ,1, /DOUBLE)
		(*square_ptr)		/= (*image_count_ptr)
		(*sigma_ptr) 		= this_scale * SQRT( (*square_ptr) - (*accum_ptr) * (*accum_ptr) )
		(*sigma_ptr)		>= 1.0d0			; trap at no smaller than unity
		;
		;	compute Median, with masking of bad values to NaNs so they aren't counted
		;
		(*median_mask_ptr)  = (*image_mask_ptr)
		(*median_mask_ptr) /= (*image_mask_ptr) 	; divide by itself to put in NaNs
		;
		(*median_ptr) 		= MEDIAN( (*image_data_ptr) * (*median_mask_ptr), DIMENSION=1 )	; median through nimages
		;
		;	recompute image mask (all within n sigma of median get 1, else get 0)
		;
		for i = 0, nimage-1 do (*image_mask_ptr)[i,*,*] =FLOAT( FLOOR( (abs( (*image_data_ptr)[i,*,*] - (*median_ptr)[*,*])/(*sigma_ptr)[*,*] ) )  )
		(*image_mask_ptr) <= 1.0
		(*image_mask_ptr) *= -1.0
		(*image_mask_ptr) += 1.0
	endfor
	;
	;	final half pass
	;
	(*image_mask_ptr) *= (*big_good_mask_ptr)	; mask with the bpm
	(*accum_ptr) 		= TOTAL(FLOAT( (*image_data_ptr) ) * (*image_mask_ptr),1,/DOUBLE)
	(*image_count_ptr) 	= TOTAL( (*image_mask_ptr) ,1,/DOUBLE)
	(*accum_ptr) 		/= (*image_count_ptr) 			; average
	;
	if(NO_OUTPUT ne 1) then begin
		;
		;	anywhere accum is 0, count0, or bad_mask, set to deleted value (0)
		;
		(*image_count_ptr) <= 1.0
		(*accum_mask_ptr) = FLOOR( (*accum_ptr) )
		(*accum_mask_ptr) <= 1
		(*accum_mask_ptr) >= 0
		;
		;	apply all the masks
		;
		(*accum_ptr) *= (*image_count_ptr) *  (*accum_mask_ptr)   					;	removed (*bad_mask_ptr) *
		(*accum_ptr) >= 0.0															; trap neg pixels
		;
		ier = write_raw1(outpath,(*accum_ptr) )
		;
		MSP_BDP_print_text,Event, "Wrote Coadded Image "+outpath+" to disk"
	endif
	;
;	raw1_to_FITS
;	stop
	;
	;	release the pointers
	;
	PTR_FREE, good_mask_ptr, image_data_ptr, image_mask_ptr, image_count_ptr
	PTR_FREE, accum_ptr, square_ptr, sigma_ptr, accum_mask_ptr
	PTR_FREE, median_ptr, product_data_mask_ptr, median_mask_ptr, big_good_mask_ptr
	;
end